@@ -1,24 +1,23 @@
-/*
- * Copyright (C) 2014-2017 Stichting Mapcode Foundation (http://www.mapcode.com)
- *
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
- *
- *    http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
- */
+// Copyright (C) 2014-2025 Stichting Mapcode Foundation (http://www.mapcode.com)
+//
+// Licensed under the Apache License, Version 2.0 (the "License");
+// you may not use this file except in compliance with the License.
+// You may obtain a copy of the License at
+//
+//    http://www.apache.org/licenses/LICENSE-2.0
+//
+// Unless required by applicable law or agreed to in writing, software
+// distributed under the License is distributed on an "AS IS" BASIS,
+// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+// See the License for the specific language governing permissions and
+// limitations under the License.
 
 #ifndef __MAPCODER_H__
 #define __MAPCODER_H__
 
 #ifdef __cplusplus
 extern "C" {
+
 #endif
 
 #include "mapcode_territories.h"
@@ -58,20 +57,28 @@ extern "C" {
 #define MAPCODE_SUPPORT_LANGUAGE_UK
 #endif
 
-#define MAPCODE_C_VERSION                   "2.5.5"
+#define MAPCODE_C_VERSION                   "2.5.6"
 #define UWORD                               unsigned short int  // 2-byte unsigned integer.
 
 #define MAX_NR_OF_MAPCODE_RESULTS           22                  // Max. number of results ever returned by encoder (e.g. for 26.904899, 95.138515).
+
 #define MAX_PRECISION_DIGITS                8                   // Max. number of extension characters (excluding the hyphen). Must be even.
 
+
 #define MAX_PROPER_MAPCODE_ASCII_LEN        11          // Max. chars in a proper mapcode (including the dot, excl. precision extension).
+
 #define MAX_ISOCODE_ASCII_LEN               7           // Max. chars in a valid ISO3166 territory code.
 #define MAX_CLEAN_MAPCODE_ASCII_LEN         (MAX_PROPER_MAPCODE_ASCII_LEN + 1 + MAX_PRECISION_DIGITS)       // Max. chars in a clean mapcode (excluding zero-terminator).
-#define MAX_MAPCODE_RESULT_ASCII_LEN        (MAX_ISOCODE_ASCII_LEN + 1 + MAX_CLEAN_MAPCODE_ASCII_LEN + 1)   // Max. chars to store a single result (including zero-terminator).
-#define MAX_TERRITORY_FULLNAME_UTF8_LEN     111 // Max. number of characters to store the longest possible territory name (in UTF8)
 
-#define MAX_MAPCODE_RESULT_UTF8_LEN         (MAX_MAPCODE_RESULT_ASCII_LEN * 3) // One mapcode character can become at most 3 UTF8characters.
-#define MAX_MAPCODE_RESULT_UTF16_LEN        (MAX_MAPCODE_RESULT_ASCII_LEN)     // Each mapcode character can become one UTF16 word.
+#define MAX_MAPCODE_RESULT_ASCII_LEN        (MAX_ISOCODE_ASCII_LEN + 1 + MAX_CLEAN_MAPCODE_ASCII_LEN + 1)   // Max. chars to store a single result (including zero-terminator).
+
+#define MAX_TERRITORY_FULLNAME_UTF8_LEN     111 // Max. number of characters to store the longest possible territory name (in UTF-8)
+
+
+#define MAX_MAPCODE_RESULT_UTF8_LEN         (MAX_MAPCODE_RESULT_ASCII_LEN * 3) // One mapcode character can become at most 3 UTF-8 characters.
+
+#define MAX_MAPCODE_RESULT_UTF16_LEN        (MAX_MAPCODE_RESULT_ASCII_LEN)     // Each mapcode character can become one UTF-16 word.
+
 
 // The constants are also exported as variables, to allow other languages to use them.
 extern char* _MAPCODE_C_VERSION;
@@ -87,31 +94,31 @@ extern int _MAX_MAPCODE_RESULT_UTF16_LEN;
 extern int _MAX_ALPHABETS_PER_TERRITORY;
 
 /**
- * The type Mapcodes hold a number of mapcodes, for example from an encoding call.
- * If a result contains a space, that space seperates the territory ISO3166 code from the mapcode.
+ * The type `Mapcodes` holds a number of Mapcodes, for example from an encoding call.
+ * If a result contains a space, that space separates the territory ISO3166 code from the mapcode.
  * International mapcodes never include a territory ISO3166 code, nor a space.
  */
 typedef struct {
-    int count;                                                               // The number of mapcode results (length of array).
-    char mapcode[MAX_NR_OF_MAPCODE_RESULTS][MAX_MAPCODE_RESULT_ASCII_LEN];   // The mapcodes.
+    int count; // The number of mapcode results (length of array).
+    char mapcode[MAX_NR_OF_MAPCODE_RESULTS][MAX_MAPCODE_RESULT_ASCII_LEN]; // The mapcodes.
 } Mapcodes;
 
 
 /**
- * The MapcodeElement structure is returned by decodeXXX and can be used to inspect or clean up the
- * mapcode input. The field territoryISO contains the cleaned up territory code from the input, but
+ * The `MapcodeElements` structure is returned by decodeXXX and can be used to inspect or clean up the
+ * mapcode input. The field `territoryISO` contains the cleaned-up territory code from the input, but
  * the code may be abbreviated, or even missing (if it wasn't available in the input).
  *
  * If you want to get a full territory code, use:
- * char isoName[MAX_ISOCODE_ASCII_LEN + 1];
- * getTerritoryIsoName(isoName, mapcodeElement.territoryCode, 0)
+ *   char isoName[MAX_ISOCODE_ASCII_LEN + 1];
+ *   getTerritoryIsoName(isoName, mapcodeElements.territoryCode, 0);
  */
 typedef struct {
-    char territoryISO[MAX_ISOCODE_ASCII_LEN + 1];           // The (trimmed and uppercased) territory code, from the input.
-    enum Territory territoryCode;                           // The territory, as recognized and disambiguated from territoryISO.
-    char properMapcode[MAX_PROPER_MAPCODE_ASCII_LEN + 1];   // The (romanised) mapcode excl. territory or extension.
-    int indexOfDot;                                         // Position of dot in properMapcode (a value between 2 and 5).
-    char precisionExtension[MAX_PRECISION_DIGITS + 1];      // The (romanised) extension (excluding the hyphen).
+    char territoryISO[MAX_ISOCODE_ASCII_LEN + 1]; // The (trimmed and uppercased) territory code, from the input.
+    enum Territory territoryCode; // The territory, as recognized and disambiguated from territoryISO.
+    char properMapcode[MAX_PROPER_MAPCODE_ASCII_LEN + 1]; // The (romanised) mapcode excl. territory or extension.
+    int indexOfDot; // Position of dot in properMapcode (a value between 2 and 5).
+    char precisionExtension[MAX_PRECISION_DIGITS + 1]; // The (romanised) extension (excluding the hyphen).
 } MapcodeElements;
 
 
@@ -119,38 +126,37 @@ typedef struct {
  * List of error return codes (negative except for ERR_OK = 0)
  */
 enum MapcodeError {
-
     // note: an incomplete mapcode could "become" complete by adding letters.
 
-    ERR_MAPCODE_INCOMPLETE = -999,   // not enough letters (yet) after dot
+    ERR_MAPCODE_INCOMPLETE = -999, // not enough letters (yet) after dot
 
     // format errors.
 
-    ERR_ALL_DIGIT_CODE = -299,       // mapcode consists only of digits
-    ERR_INVALID_MAPCODE_FORMAT,      // string not recognized as mapcode format
-    ERR_INVALID_CHARACTER,           // mapcode contains an invalid character
-    ERR_BAD_ARGUMENTS,               // an argument is invalid (e.g. NULL)
-    ERR_INVALID_ENDVOWELS,           // mapcodes ends in UE or UU
-    ERR_EXTENSION_INVALID_LENGTH,    // precision extension too long, or empty
+    ERR_ALL_DIGIT_CODE = -299, // mapcode consists only of digits
+    ERR_INVALID_MAPCODE_FORMAT, // string not recognized as mapcode format
+    ERR_INVALID_CHARACTER, // mapcode contains an invalid character
+    ERR_BAD_ARGUMENTS, // an argument is invalid (e.g. NULL)
+    ERR_INVALID_ENDVOWELS, // mapcode ends in UE or UU
+    ERR_EXTENSION_INVALID_LENGTH, // precision extension too long, or empty
     ERR_EXTENSION_INVALID_CHARACTER, // bad precision extension character (e.g. Z)
-    ERR_UNEXPECTED_DOT,              // mapcode dot can not be in this position
-    ERR_DOT_MISSING,                 // mapcode dot not found
-    ERR_UNEXPECTED_HYPHEN,           // hyphen can not be in this position
-    ERR_INVALID_VOWEL,               // vowel in invalid location, or missing
-    ERR_BAD_TERRITORY_FORMAT,        // mapcode territory badly formatted
-    ERR_TRAILING_CHARACTERS,         // characters found trailing the mapcode
+    ERR_UNEXPECTED_DOT, // mapcode dot can not be in this position
+    ERR_DOT_MISSING, // mapcode dot not found
+    ERR_UNEXPECTED_HYPHEN, // hyphen can not be in this position
+    ERR_INVALID_VOWEL, // vowel in invalid location, or missing
+    ERR_BAD_TERRITORY_FORMAT, // mapcode territory badly formatted
+    ERR_TRAILING_CHARACTERS, // characters found trailing the mapcode
 
     // parse errors.
 
-    ERR_UNKNOWN_TERRITORY = -199,    // mapcode territory not recognized
+    ERR_UNKNOWN_TERRITORY = -199, // mapcode territory not recognized
 
     // other errors.
 
-    ERR_BAD_MAPCODE_LENGTH = -99,    // proper mapcode too short or too long
-    ERR_MISSING_TERRITORY,           // mapcode can not be decoded without territory
-    ERR_EXTENSION_UNDECODABLE,       // extension does not decode to valid coordinate
-    ERR_MAPCODE_UNDECODABLE,         // mapcode does not decode inside territory
-    ERR_BAD_COORDINATE,              // latitude or longitude is NAN or infinite
+    ERR_BAD_MAPCODE_LENGTH = -99, // proper mapcode too short or too long
+    ERR_MISSING_TERRITORY, // mapcode can not be decoded without territory
+    ERR_EXTENSION_UNDECODABLE, // extension does not decode to valid coordinate
+    ERR_MAPCODE_UNDECODABLE, // mapcode does not decode inside territory
+    ERR_BAD_COORDINATE, // latitude or longitude is NaN or infinite
 
     // all OK.
 
@@ -172,27 +178,25 @@ enum MapcodeError {
  *                        make them represent the coordinate more accurately.
  *
  * Returns:
- *      Number of results stored in parameter results. Always >= 0 (0 if no encoding was possible or an error occurred).
- *      The results are stored as pairs (Mapcode, territory name) in:
- *          (results[0], results[1])...(results[(2 * N) - 2], results[(2 * N) - 1])
+ *      Number of results stored in `mapcodes->count`. Always >= 0 (0 if no encoding was possible or an error occurred).
+ *      Each resulting string is stored in `mapcodes->mapcode[i]` and may include a territory ISO3166 code followed by a space when applicable.
  */
 
 int encodeLatLonToMapcodes(
-        Mapcodes *mapcodes,
-        double latDeg,
-        double lonDeg,
-        enum Territory territory,
-        int extraDigits);
+    Mapcodes* mapcodes,
+    double latDeg,
+    double lonDeg,
+    enum Territory territory,
+    int extraDigits);
 
 
 /**
  * Encode a latitude, longitude pair (in degrees) to a single Mapcode: the shortest possible for the given territory
- * (which can be 0 for all territories).
+ * (pass TERRITORY_NONE or TERRITORY_UNKNOWN to consider all territories).
  *
  * Arguments:
- *      result          - Returned Mapcode. The caller must not allocate or de-allocated this string.
- *                        The resulting string MUST be allocated (and de-allocated) by the caller.
- *                        The caller should allocate at least MAX_MAPCODE_RESULT_ASCII_LEN characters for the string.
+ *      mapcode         - Output buffer for the resulting Mapcode. The caller must allocate this buffer
+ *                        with capacity of at least MAX_MAPCODE_RESULT_ASCII_LEN characters.
  *      lat             - Latitude, in degrees. Range: -90..90.
  *      lon             - Longitude, in degrees. Range: -180..180.
  *      territory       - Territory (e.g. as obtained from getTerritoryCode), used as encoding context.
@@ -205,11 +209,11 @@ int encodeLatLonToMapcodes(
  *      Number of results. <=0 if encoding failed, or 1 if it succeeded.
  */
 int encodeLatLonToSingleMapcode(
-        char *mapcode,
-        double latDeg,
-        double lonDeg,
-        enum Territory territory,
-        int extraDigits);
+    char* mapcode,
+    double latDeg,
+    double lonDeg,
+    enum Territory territory,
+    int extraDigits);
 
 
 /**
@@ -218,9 +222,8 @@ int encodeLatLonToSingleMapcode(
  * (like Swift).
  *
  * Arguments:
- *      result          - Returned Mapcode. The caller must not allocate or de-allocated this string.
- *                        The resulting string MUST be allocated (and de-allocated) by the caller.
- *                        The caller should allocate at least MAX_MAPCODE_RESULT_ASCII_LEN characters for the string.
+ *      mapcode         - Output buffer for the resulting Mapcode. The caller must allocate this buffer
+ *                        with capacity of at least MAX_MAPCODE_RESULT_ASCII_LEN characters.
  *      lat             - Latitude, in degrees. Range: -90..90.
  *      lon             - Longitude, in degrees. Range: -180..180.
  *      territory       - Territory (e.g. as obtained from getTerritoryCode), used as encoding context.
@@ -236,7 +239,7 @@ int encodeLatLonToSingleMapcode(
  *      Total number of results available for selection. <=0 if encoding failed, or >0 if it succeeded.
  */
 int encodeLatLonToSelectedMapcode(
-    char *mapcode,
+    char* mapcode,
     double latDeg,
     double lonDeg,
     enum Territory territory,
@@ -245,7 +248,7 @@ int encodeLatLonToSelectedMapcode(
 
 
 /**
- * Decode a utf8 or ascii Mapcode to  a latitude, longitude pair (in degrees).
+ * Decode a UTF-8 or ASCII Mapcode to a latitude/longitude pair (in degrees).
  *
  * Arguments:
  *      lat             - Decoded latitude, in degrees. Range: -90..90.
@@ -256,36 +259,36 @@ int encodeLatLonToSelectedMapcode(
  *      mapcodeElements - If not NULL, filled with analysis of the string (unless an error was encountered).
  *
  * Returns:
- *      ERR_OK if encoding succeeded.
+ *      ERR_OK if decoding succeeded.
  */
 enum MapcodeError decodeMapcodeToLatLonUtf8(
-        double *latDeg,
-        double *lonDeg,
-        const char *utf8string,
-        enum Territory territory,
-        MapcodeElements *mapcodeElements);
+    double* latDeg,
+    double* lonDeg,
+    const char* utf8string,
+    enum Territory territory,
+    MapcodeElements* mapcodeElements);
 
 
 /**
- * Decode a utf16 Mapcode to  a latitude, longitude pair (in degrees).
+ * Decode a UTF-16 Mapcode to a latitude/longitude pair (in degrees).
  *
  * Arguments:
  *      lat             - Decoded latitude, in degrees. Range: -90..90.
  *      lon             - Decoded longitude, in degrees. Range: -180..180.
- *      mapcodeElements - If not NULL, filled with analysis of the string (unless an error was encountered)
- *      utf8string      - Mapcode to decode (ascii or utf8 string).
+ *      utf16string     - Mapcode to decode (UTF-16 string).
  *      territory       - Territory (e.g. as obtained from getTerritoryCode), used as decoding context.
  *                        Pass TERRITORY_NONE if not available.
+ *      mapcodeElements - If not NULL, filled with analysis of the string (unless an error was encountered).
  *
  * Returns:
- *      ERR_OK if encoding succeeded.
+ *      ERR_OK if decoding succeeded.
  */
 enum MapcodeError decodeMapcodeToLatLonUtf16(
-        double *latDeg,
-        double *lonDeg,
-        const UWORD *utf16string,
-        enum Territory territory,
-        MapcodeElements *mapcodeElements);
+    double* latDeg,
+    double* lonDeg,
+    const UWORD* utf16string,
+    enum Territory territory,
+    MapcodeElements* mapcodeElements);
 
 
 /**
@@ -293,7 +296,7 @@ enum MapcodeError decodeMapcodeToLatLonUtf16(
  * the return value ERR_OK indicates the string has the Mapcode format, much like string comparison strcmp returns.)
  *
  * Arguments:
- *      utf8String/utf16String - Mapcode string to check, in UTF8 or UTF16 format.
+ *      utf8String/utf16String - Mapcode string to check, in UTF-8 or UTF-16 format.
  *
  * Returns:
  *      ERR_OK if the string has a correct Mapcode format, another ERR_XXX value if the string does
@@ -303,46 +306,46 @@ enum MapcodeError decodeMapcodeToLatLonUtf16(
  *      NOTE: a correct Mapcode format does not in itself guarantee the mapcode will decode to
  *      a valid coordinate!
  */
-enum MapcodeError compareWithMapcodeFormatUtf8(const char *utf8String);
+enum MapcodeError compareWithMapcodeFormatUtf8(const char* utf8String);
 
-enum MapcodeError compareWithMapcodeFormatUtf16(const UWORD *utf16String);
+enum MapcodeError compareWithMapcodeFormatUtf16(const UWORD* utf16String);
 
 
 /**
  * Convert an ISO3166 territory code to a territory.
  *
  * Arguments:
- *      territoryISO         - String starting with ISO3166 code of territory (e.g. "USA" or "US-CA").
- *      parentTerritoryCode  - Parent territory, or TERRITORY_NONE if not available.
+ *      territoryISO               - String starting with ISO3166 code of territory (e.g. "USA" or "US-CA").
+ *      optionalTerritoryContext   - Parent territory, or TERRITORY_NONE if not available.
  *
  * Returns:
  *      Territory (> _TERRITORY_MIN) if succeeded, or TERRITORY_NONE if failed.
  */
 enum Territory getTerritoryCode(
-        const char *territoryISO,
-        enum Territory optionalTerritoryContext);
+    const char* territoryISO,
+    enum Territory optionalTerritoryContext);
 
 
 /**
  * Convert a territory to a territory name.
  *
  * Arguments:
- *      territoryISO    - String to territory ISO code name result.
+ *      territoryISO    - Output buffer for the territory ISO code name.
  *      territory       - Territory to get the name of.
- *      userShortName   - Pass 0 for full name, 1 for short name (state codes may be ambiguous).
+ *      useShortName    - Pass 0 for full name, 1 for short name (state codes may be ambiguous).
  *
  * Returns:
  *      Pointer to result. String will be empty if territory illegal.
  */
-char *getTerritoryIsoName(
-        char *territoryISO,
-        enum Territory territory,
-        int useShortName);
+char* getTerritoryIsoName(
+    char* territoryISO,
+    enum Territory territory,
+    int useShortName);
 
 
 /**
- * Given a territory, return the territory itself it it was a country, or return its parent
- * territory if it was a subdivision (e.g. a state).
+ * Given a territory, return the territory itself if it is a country, or return its parent
+ * territory if it is a subdivision (e.g. a state).
  *
  * Arguments:
  *      territory   - territory (either a country or a subdivision, e.g. a state).
@@ -398,21 +401,21 @@ double maxErrorInMeters(int extraDigits);
  * Return value:
  *      0 if coordinate is NOT near more than one territory border, non-0 otherwise.
  *
- * Note that for the mapcode system, the following should hold: IF a point p has a 
+ * Note that for the mapcode system, the following should hold: IF a point p has a
  * mapcode M, THEN decode(M) delivers a point q within maxErrorInMeters() of p.
  * Furthermore, encode(q) must yield back M *unless* point q is near multiple borders.
  */
 int multipleBordersNearby(
-        double latDeg,
-        double lonDeg,
-        enum Territory territory);
+    double latDeg,
+    double lonDeg,
+    enum Territory territory);
 
 
 /**
  * Returns territory names in English. There's always at least 1 alternative (with index 0).
  *
  *   Arguments:
- *       territoryName - Target string, allocated by caller to be at least MAX_TERRITORY_FULLNAME_ASCII_LEN + 1 bytes.
+ *       territoryName - Target string, allocated by caller to be at least MAX_TERRITORY_FULLNAME_UTF8_LEN + 1 bytes.
  *       territory     - Territory to get name for.
  *       alternative   - Which name to get, must be >= 0 (0 = default, 1 = first alternative, 2 = second etc.).
  *
@@ -421,9 +424,9 @@ int multipleBordersNearby(
  *       non-0 if the alternative exists (territoryName contains name).
  */
 int getFullTerritoryNameEnglish(
-        char *territoryName,
-        enum Territory territory,
-        int alternative);
+    char* territoryName,
+    enum Territory territory,
+    int alternative);
 
 
 /**
@@ -442,15 +445,15 @@ int getFullTerritoryNameEnglish(
  *       non-0 if the alternative exists (territoryName contains name).
  */
 int getFullTerritoryNameLocalUtf8(
-        char *territoryName,
-        enum Territory territory,
-        int alternative);
+    char* territoryName,
+    enum Territory territory,
+    int alternative);
 
 int getFullTerritoryNameLocalInAlphabetUtf8(
-        char *territoryName,
-        enum Territory territory,
-        int alternative,
-        enum Alphabet alphabet);
+    char* territoryName,
+    enum Territory territory,
+    int alternative,
+    enum Alphabet alphabet);
 
 
 /**
@@ -470,21 +473,21 @@ int getFullTerritoryNameLocalInAlphabetUtf8(
  *       non-0 if the alternative exists (territoryName contains name).
  */
 int getFullTerritoryNameInLocaleUtf8(
-        char *territoryName,
-        enum Territory territory,
-        int alternative,
-        const char *locale);
+    char* territoryName,
+    enum Territory territory,
+    int alternative,
+    const char* locale);
 
 int getFullTerritoryNameInLocaleInAlphabetUtf8(
-        char *territoryName,
-        enum Territory territory,
-        int alternative,
-        const char *locale,
-        enum Alphabet alphabet);
+    char* territoryName,
+    enum Territory territory,
+    int alternative,
+    const char* locale,
+    enum Alphabet alphabet);
 
 
 /**
- * This struct contains the returned alphabest for getAlphabetsForTerritory. The 'count' specifies
+ * This struct contains the returned alphabets for getAlphabetsForTerritory. The 'count' specifies
  * how many alphabets are listed in 'alphabet', range [1, MAX_ALPHABETS_PER_TERRITORY].
  */
 #define MAX_ALPHABETS_PER_TERRITORY 3
@@ -504,9 +507,9 @@ typedef struct {
  *
  * Returns:
  *      A pointer to a TerritoryAlphabets structure, or NULL if the territory is invalid.
- *      (The pointer is owned by the library and should not be dealloacted by the caller.)
+ *      (The pointer is owned by the library and should not be deallocated by the caller.)
  */
-const TerritoryAlphabets *getAlphabetsForTerritory(enum Territory territory);
+const TerritoryAlphabets* getAlphabetsForTerritory(enum Territory territory);
 
 
 /**
@@ -519,9 +522,9 @@ const TerritoryAlphabets *getAlphabetsForTerritory(enum Territory territory);
  *      alphabet     - Alphabet to use.
  *
  * Returns:
- *      Encode UTF8 string (pointer to utf8String buffer), allocated and deallocated by the caller.
+ *      Encoded UTF-8 string (pointer to utf8String buffer), allocated and deallocated by the caller.
  */
-char *convertMapcodeToAlphabetUtf8(char *utf8String, const char *asciiString, enum Alphabet alphabet);
+char* convertMapcodeToAlphabetUtf8(char* utf8String, const char* asciiString, enum Alphabet alphabet);
 
 
 /**
@@ -534,9 +537,9 @@ char *convertMapcodeToAlphabetUtf8(char *utf8String, const char *asciiString, en
  *      alphabet     - Alphabet to use.
  *
  * Returns:
- *      Encode UTF16 string (pointer to utf16String buffer), allocated and deallocated by the caller.
+ *      Encoded UTF-16 string (pointer to utf16String buffer), allocated and deallocated by the caller.
  */
-UWORD *convertMapcodeToAlphabetUtf16(UWORD *utf16String, const char *asciiString, enum Alphabet alphabet);
+UWORD* convertMapcodeToAlphabetUtf16(UWORD* utf16String, const char* asciiString, enum Alphabet alphabet);
 
 
 #ifdef __cplusplus
